# Confirmation AEA AW1

An agent that manages confirmation of registration for Agent World 1.

## Description

This agent uses the `fetchai/simple_service_registration` skill to register itself on the sOEF. The `fetchai/confirmation_aw1` skill, is used to handle incoming registration requests, verifying the data contained in them and responding with an outcome (success/error). For successful registrations it transfers test-net wealth to the sender of the request.

## Links
